summaryrefslogtreecommitdiff
path: root/jstests/auth/system_user_exception.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/auth/system_user_exception.js')
-rw-r--r--jstests/auth/system_user_exception.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/auth/system_user_exception.js b/jstests/auth/system_user_exception.js
index 67814119541..78dff98a8a9 100644
--- a/jstests/auth/system_user_exception.js
+++ b/jstests/auth/system_user_exception.js
@@ -7,13 +7,13 @@
var m = MongoRunner.runMongod(
{keyFile: "jstests/libs/key1", setParameter: "authenticationMechanisms=PLAIN"});
// Verify that it's possible to use SCRAM-SHA-1 to authenticate as the __system@local user
assert.eq(1,
- m.getDB("local").auth({user: "__system", pwd: "foopdedoop", mechanism: "SCRAM-SHA-1"}));
+ m.getDB("local").auth({user: "__system", pwd: "foopdedoop", mechanism: "SCRAM-SHA-256"}));
// Verify that it is not possible to authenticate other users
m.getDB("test").runCommand({createUser: "guest", pwd: "guest", roles: jsTest.readOnlyUserRoles});
-assert.eq(0, m.getDB("test").auth({user: "guest", pwd: "guest", mechanism: "SCRAM-SHA-1"}));
+assert.eq(0, m.getDB("test").auth({user: "guest", pwd: "guest", mechanism: "SCRAM-SHA-256"}));
MongoRunner.stopMongod(m);
})();
@@ -7,13 +7,13 @@
var m = MongoRunner.runMongod(
{keyFile: "jstests/libs/key1", setParameter: "authenticationMechanisms=PLAIN"});
-// Verify that it's possible to use SCRAM-SHA-1 to authenticate as the __system@local user
+// Verify that it's possible to use SCRAM-SHA-256 to authenticate as the __system@local user
assert.eq(1,